package com.fractalite.hermes.teldar.services;

import java.text.ParseException;

import javax.xml.datatype.DatatypeConfigurationException;

import org.apache.camel.Exchange;
import org.apache.camel.InvalidPayloadException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.fractalite.hermes.teldar.cfg.TeldarRouteBuilder;
import com.fractalite.hermes.teldar.tools.ObjectToXml;
import com.fractalite.models.commerce.Order;
import com.fractalite.models.travel.PaxType;
import com.fractalite.models.travel.Traveller;
import com.fractalite.models.travel.stay.HotelStay;
import com.fractalite.models.travel.stay.Room;
import com.fractalite.models.travel.stay.StayItem2;
import com.gekko_holding.webservice.v2_4.BookHotel;
import com.gekko_holding.webservice.v2_4.BookedOffer;
import com.gekko_holding.webservice.v2_4.BookedRoom;
import com.gekko_holding.webservice.v2_4.CustomerIdentification;
import com.gekko_holding.webservice.v2_4.HotelBooking;
import com.gekko_holding.webservice.v2_4.Pax;
import com.gekko_holding.webservice.v2_4.RequestedBookings;
import com.gekko_holding.webservice.v2_4.StaticticField;

public class ConfirmBookTeldarRequest extends TeldarServices {

	protected static Logger logger = LoggerFactory.getLogger(ConfirmBookTeldarRequest.class);

	@Override
	public void process(Exchange exchange)
			throws InvalidPayloadException, DatatypeConfigurationException, ParseException {

		logger.info("Invoking TELDAR ConfirmBookTeldarRequest Processor.......");
		Order order = exchange.getIn().getMandatoryBody(Order.class);
		exchange.setProperty("order", order);
		logger.info("Order is " + ObjectToXml.printXML(order));
		String custoNumber = "Av" + (System.currentTimeMillis() / 1000l);
		exchange.setProperty("custoNumber", custoNumber);
		BookHotel book = addBookhotel(order, custoNumber);
		logger.info("End TELDAR ConfirmBookTeldarRequest Processor....... \n" + ObjectToXml.printXML(book));
		exchange.getIn().setBody(book, BookHotel.class);
	}

	public BookHotel addBookhotel(Order order, String custonumber) throws DatatypeConfigurationException {

		BookHotel bookhotel = new BookHotel();
		CustomerIdentification customeridentification = new CustomerIdentification();

		customeridentification.setClientId(TeldarRouteBuilder.clientId);
		customeridentification.setPassword(TeldarRouteBuilder.password);
		customeridentification.setCustomerKey(TeldarRouteBuilder.customerKey);

		HotelStay hotelstay = ((HotelStay) order.getTrip().getContent().get(0));

		bookhotel.setLanguage("EN");
		bookhotel.setIdentification(customeridentification);

		RequestedBookings requestbooking = new RequestedBookings();
		requestbooking.setInsurance(false);

		RequestedBookings.StatisticalFields satisticalfields = new RequestedBookings.StatisticalFields();
		StaticticField staticticField = new StaticticField();
		staticticField.setType("RM_EXTERNAL_REF");
		staticticField.setValue(custonumber);
		logger.info("avvvv" + custonumber);

		satisticalfields.getStatisticalField().add(staticticField);

		requestbooking.setStatisticalFields(satisticalfields);

		HotelBooking hotelbooking = new HotelBooking();
		hotelbooking.setHotelCode(hotelstay.getHotel().getCode());

		hotelbooking.setCheckIn(hotelstay.getCheckin().toString());
		hotelbooking.setCheckOut(hotelstay.getCheckout().toString());

		BookedOffer bookedoffer = new BookedOffer();
		bookedoffer.setCode(order.getNumber());

		BookedOffer.BookedRooms bookedRooms = new BookedOffer.BookedRooms();
		int roomId = 0;
		for (StayItem2 item : order.getPricing().getItems(StayItem2.class)) // Item
		{
			for (Room room : item.getRooms()) {
				BookedRoom bookedroom2 = new BookedRoom();
				bookedroom2.setRoomIndex(roomId++);
				for (Traveller tr : room.getGuests()) {
					Pax pax2 = new Pax();
					pax2.setTitle("Mr");
					if (tr.getClassification() == PaxType.CHILD) {
						pax2.setIsChild(true);
						pax2.setChildAge("" + tr.getAge());
					}

					else if (tr.getClassification() == PaxType.INFANT) {

						pax2.setIsChild(true);
						pax2.setChildAge("" + tr.getAge());
					}

					pax2.setFirstName(tr.getName().getFirst());
					pax2.setLastName(tr.getName().getLast());
					bookedroom2.getRegisteredUserOrPax().add(pax2);
				}
				bookedRooms.getBookedRoom().add(bookedroom2);
			}
		}

		bookedoffer.setBookedRooms(bookedRooms);

		hotelbooking.setBookedOffer(bookedoffer);

		requestbooking.getHotelBooking().add(hotelbooking);

		bookhotel.setBookRequest(requestbooking);

		return bookhotel;

	}

}
